@@ -137,6 +137,7 @@ class UserCommands(enum.Enum):
     Allowed user commands
     """
 
+    RELOAD_CONFIG = "reload_config"
     RELOAD_SCRIPT = "reload_script"
     CLEAR_PLOTTING_CACHE = "clear_plotting_cache"
     CLEAR_SIMULATED_ORDERS_CACHE = "clear_simulated_orders_cache"
@@ -368,3 +369,19 @@ class SignalBundlesAttrs(enum.Enum):
 class SignalsAttrs(enum.Enum):
     TOPIC = "topic"
     CONTENT = "content"
+
+
+class InitializationEventTopics(enum.Enum):
+    EXCHANGE = "exchanges"
+
+
+class InitializationEventExchangeTopics(enum.Enum):
+    POSITIONS = "positions"
+    BALANCE = "balance"
+    ORDERS = "orders"
+    TRADES = "trades"
+    CONTRACTS = "contracts"
+    CANDLES = "candles"
+    PRICE = "price"
+    ORDER_BOOK = "order_book"
+    FUNDING = "funding"
